import logging
import time
from typing import List

logger = logging.getLogger()


def execute_transformations(commands: List[str], engine):
    try:
        with engine.connect() as connection:
            for command in commands:
                logger.debug(f"Ejecutando comando de transformación: {command}")
                _ = connection.execute(command)
    except Exception as e:
        logger.error(f"Error ejecutando comando de transformación. {e}")


def delete_table(tablename: str, engine) -> bool:
    delete = False
    try:
        command = f'DROP TABLE IF EXISTS {tablename}'
        start_time = time.time()
        with engine.connect() as conn:
            try:
                _ = conn.execute(command)
            except Exception as e:
                logger.error(f"Tabla no encontrada. {e}")
        delete = True
        logger.debug(f"Duración de borrado: {time.time() - start_time}")
    except Exception as e:
        logger.error(f"Error borrando tabla {tablename}. {e}")
    finally:
        return delete


def delete_procedure(procedure: str, engine) -> bool:
    delete = False
    try:
        command = f"DROP PROCEDURE IF EXISTS {procedure}"
        start_time = time.time()
        with engine.connect() as conn:
            try:
                _ = conn.execute(command)
            except Exception as e:
                logger.error(f"Procedure no encontrado. {e}")
        delete = True
        logger.debug(f"Duración de borrado: {time.time() - start_time}")
    except Exception as e:
        logger.error(f"Error borrando procedure {procedure}. {e}")
    finally:
        return delete
